@@ -6,6 +6,10 @@ from typing import List, Optional
 
 import humanize
 
+import darwin.exporter as exporter
+import darwin.exporter.formats
+import darwin.importer as importer
+import darwin.importer.formats
 from darwin.client import Client
 from darwin.config import Config
 from darwin.dataset.identifier import DatasetIdentifier
@@ -85,7 +89,7 @@ def authenticate(
 def current_team():
     """Print the team currently authenticated against"""
     client = _load_client()
-    print(client.team)
+    print(client.default_team)
 
 
 def list_teams():
@@ -335,6 +339,43 @@ def upload_data(
         _error(f"No files found")
 
 
+def dataset_import(dataset_slug, format, files):
+    client = _load_client()
+    parser = find_supported_format(format, darwin.importer.formats.supported_formats)
+
+    try:
+        dataset = client.get_remote_dataset(dataset_identifier=dataset_slug)
+        importer.import_annotations(dataset, parser, files)
+    except NotFound as e:
+        _error(f"No dataset with name '{e.name}'")
+
+
+def find_supported_format(query, supported_formats):
+    for (fmt, fmt_parser) in supported_formats:
+        if fmt == query:
+            return fmt_parser
+    list_of_formats = ", ".join([fmt for fmt, _ in supported_formats])
+    _error(f"Unsupported format, currently supported: {list_of_formats}")
+
+
+def dataset_convert(dataset_slug, format, output_dir):
+    client = _load_client()
+    parser = find_supported_format(format, darwin.exporter.formats.supported_formats)
+
+    try:
+        dataset = client.get_remote_dataset(dataset_identifier=dataset_slug)
+        if not dataset.local_path.exists():
+            _error(f"No annotations download for dataset f{dataset}, first pull a release")
+        exporter.export_annotations(parser, [dataset.local_path], output_dir)
+    except NotFound as e:
+        _error(f"No dataset with name '{e.name}'")
+
+
+def convert(format, files, output_dir):
+    parser = find_supported_format(format, darwin.exporter.formats.supported_formats)
+    exporter.export_annotations(parser, files, output_dir)
+
+
 def help(parser, subparser: Optional[str] = None):
     if subparser:
         parser = next(
